@@ -1,5 +1,6 @@
-#!/usr/local/bin/dumb-init /bin/bash
+#!/bin/bash
 set -o errexit
+set -o xtrace
 
 # Processing /var/lib/kolla/config_files/config.json as root.  This is necessary
 # to permit certain files to be controlled by the root user which should
@@ -8,6 +9,9 @@ sudo -E kolla_set_configs
 CMD=$(cat /run_command)
 ARGS=""
 
+# Install/remove custom CA certificates
+sudo kolla_copy_cacerts
+
 if [[ ! "${!KOLLA_SKIP_EXTEND_START[@]}" ]]; then
     # Run additional commands if present
     . kolla_extend_start
